#!/bin/bash

#
# Factorize for 2016.1
#

KRCFG="$(which kreadconfig)"

if [ ! -z "$KRCFG" ]; then # Check if kde is installed, otherwise do nothing

    # Powersave applet
    CFGFILE="/etc/sysconfig/harddrake2/kernel"
    PSAVE=$(kreadconfig --group "Mandriva" --key "PowersaveApplet" --default "false")
    LAP=$(kreadconfig --file "/etc/sysconfig/harddrake2/kernel" --key IS_LAPTOP --default "false")

    if [ "$LAP" = "true" ]; then
        if [ ! "$PSAVE" = "true" ]; then
            if [ ! -f "$HOME/.kde4/share/config/plasma-desktop-appletsrc" ]; then
                mkdir -p $HOME/.kde4/share/config
                cat >> $HOME/.kde4/share/config/plasma-desktop-appletsrc << EOF

[Containments][2][Applets][9][Configuration][Applets][19]
geometry=298,0,24,24
immutability=1
plugin=battery
zvalue=0

[Containments][2][Applets][9][Configuration][Applets][19][Configuration]
Share=false
showMultipleBatteries=false

[Containments][2][Applets][9][Configuration][Applets][19][Configuration][ExtenderItems][4]
extenderIconName=battery
extenderItemName=powermanagement
extenderItemPosition=0
isCollapsed=false
sourceAppletId=19
sourceAppletPluginName=battery
EOF
                kwriteconfig --group "Mandriva" --key "PowersaveApplet" --type "bool" 1
            fi
        fi
    fi

    OLDICON=$(kreadconfig --group "Mandriva" --key "IconMigration" --default "false")
    if [ ! "$OLDICON" = "true" ]; then
        # We need to remove the old mdv icons ( music, video, download ) and use KDE ones instead
        MUSICDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_MUSIC_DIR)" )
        if [ -z "$MUSICDIR" ]; then
            MUSICDIR="$HOME/Music"
        fi

        if [ ! -e "$MUSICDIR/.directory" ]; then
            cat >> "$MUSICDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-sound
EOF
        fi

        DLDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DOWNLOAD_DIR)" )

        if [ -z "$DLDIR" ]; then
            DLDIR="$HOME/Download"
        fi

        if [ ! -e "$DLDIR/.directory" ]; then
            cat >> "$DLDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-downloads
EOF
        fi

        DOCDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DOCUMENTS_DIR)" )

        if [ -z "$DOCDIR" ]; then
            DOCDIR="$HOME/Download"
        fi

        if [ ! -e "$DOCDIR/.directory" ]; then
            cat >> "$DOCDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-documents
EOF
        fi

        PICTUREDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_PICTURES_DIR)" )

        if [ -z "$PICTUREDIR" ]; then
            PICTUREDIR="$HOME/Picture"
        fi

        if [ ! -e "$PICTUREDIR/.directory" ]; then
            cat >> "$PICTUREDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-image
EOF
        fi

        VIDEOSDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_VIDEOS_DIR)" )

        if [ -z "$VIDEOSDIR" ]; then
            VIDEOSDIR="$HOME/Video"
        fi

        if [ ! -e "$VIDEOSDIR/.directory" ]; then
            cat >> "$VIDEOSDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-video
EOF
        fi
        kwriteconfig --group "Mandriva" --key "IconMigration" --type "bool" 1
    fi

    if [ ! -f "$HOME/.gtkrc-2.0-kde" ]; then
        ### rosa-elementary theme apply #####
        cat >> $HOME/.gtkrc-2.0-kde << EOF
include "/usr/share/themes/rosa-elementary/gtk-2.0/gtkrc"
include "/etc/gtk-2.0/gtkrc"
style "user-font"
{
        font_name="Droid Sans Regular"
}
widget_class "*" style "user-font"
gtk-font-name="Droid Sans Regular 10"
gtk-theme-name="rosa-elementary"
gtk-icon-theme-name="rosa"
gtk-fallback-icon-theme="gnome"
gtk-toolbar-style=GTK_TOOLBAR_ICONS
gtk-menu-images=0
gtk-button-images=0
EOF
        ln -s --relative $HOME/.gtkrc-2.0-kde $HOME/.gtkrc-2.0-kde4
        mkdir -p $HOME/.kde4/env/
        cat >>$HOME/.kde4/env/gtk2-engine.sh <<EOF
export GTK2_RC_FILES=$HOME/.gtkrc-2.0-kde4
EOF
        export GTK2_RC_FILES=$HOME/.gtkrc-2.0-kde4
        ####workaround for sound on some machines####
        alsactl restore
        amixer set Master 33%
    fi

    if [ ! -f "$HOME/.config/gtk-3.0/settings.ini" ]; then
        ### rosa-elementary theme apply #####
        cat >> $HOME/.config/gtk-3.0/settings.ini << EOF
[Settings]
gtk-font-name=Droid Sans Regular 10
gtk-theme-name=rosa-elementary
gtk-icon-theme-name=rosa
gtk-fallback-icon-theme=gnome
gtk-toolbar-style=GTK_TOOLBAR_ICONS
gtk-menu-images=0
gtk-button-images=0
EOF
    fi

    if [ ! -f "$HOME/.config/kdeglobals" ]; then
        ### gtk2 qt5 style apply #####
        cat >> $HOME/.config/kdeglobals << EOF
[KDE]
widgetStyle=gtk2
EOF
    fi

    # We do not want the trash desktop file in the desktop by default
    TRASH=$(kreadconfig --group "Mandriva" --key "Trash" --default "false")
    if [ ! "$TRASH" = "true" ]; then
        # We should handle i18n dir modes in xgd user dirs
        DIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DESKTOP_DIR)" )
        if [ -z "$DIR" ]; then
            DIR="$HOME/Desktop"
        fi

        if [ -f "${DIR}/trash.desktop" ]; then
            rm -f "${DIR}/trash.desktop"
        fi
            kwriteconfig --group "Mandriva" --key "Trash" --type "bool" 1
    fi

    # Create symbolic link to the stackfolders help document in the download folder
    FIRSTRUN=$(kreadconfig --group "Mandriva" --key "FirstRun" --default "true")
    if [ "$FIRSTRUN" = "true" ]; then
        DOC_DIR=/usr/share/doc/plasma-applet-stackfolder/
        if [ -z "$(echo "$LANG" | grep "ru_RU")" ]; then
            DOC_FILE=$DOC_DIR/"welcome-en.pdf"
            DOC_LINK=$DLDIR/"Welcome.pdf"
        else
            DOC_FILE=$DOC_DIR/"welcome-ru.pdf"
            DOC_LINK=$DLDIR/"Добро пожаловать.pdf"
        fi

        if [ -e "$DOC_FILE" ]; then
            if [ ! -e "$DOC_LINK" ]; then
                ln -s "$DOC_FILE" "$DOC_LINK"
            fi
        fi
        kwriteconfig --group "Mandriva" --key "FirstRun" --type "bool" "false"
    fi
fi
chmod 0666 $HOME/.face.icon
#end of kde check

